@@ -502,7 +502,8 @@ public class Mail {
 		buf.append("To: ").append(arrayToCommaDelimitedString(to)).append("\n");
 		buf.append("Cc: ").append(arrayToCommaDelimitedString(cc)).append("\n");
 		buf.append("Bcc: ").append(arrayToCommaDelimitedString(bcc)).append("\n");
-		buf.append("Reply-To: ").append(replyTo != null ? replyTo.toUnicodeString() : null).append("\n");
+		buf.append("Reply-To: ").append(replyTo != null ? replyTo.toUnicodeString() : null).append(
+				"\n");
 		buf.append("Subject: ").append(subject).append("\n");
 
 		if (xHeaders != null) {
@@ -656,6 +657,22 @@ public class Mail {
 		attachmentFiles.add(new AttachmentFile(fileName, is));
 	}
 
+	/**
+	 * ꤵ줿byteեȤźդޤ
+	 * ꤹե̾ˤŬڤʳĥҤդƤɬפޤ
+	 * 
+	 * @since 1.1.7
+	 * 
+	 * @param bytes źեեbyte
+	 * @param fileName ե̾
+	 */
+	public void addFile(byte[] bytes, String fileName) {
+		if (attachmentFiles == null) {
+			initAttachmentFiles();
+		}
+		attachmentFiles.add(new AttachmentFile(fileName, bytes));
+	}
+
 	/**
 	 * attachmentFilesץѥƥ
 	 */
@@ -741,6 +758,8 @@ public class Mail {
 
 		private URL url;
 
+		private byte[] bytes = null;
+
 		/**
 		 * ե̾ȥեꤷơΥ饹Υ󥿥󥹤ޤ
 		 * ե̾ˤŬڤʳĥҤդƤɬפޤ
@@ -777,6 +796,18 @@ public class Mail {
 			this.url = url;
 		}
 
+		/**
+		 * ե̾byteꤷơΥ饹Υ󥿥󥹤ޤ
+		 * ե̾ˤŬڤʳĥҤդƤɬפޤ
+		 * 
+		 * @param name ᡼ɽե̾
+		 * @param bytes źեեbyte
+		 */
+		public AttachmentFile(String name, byte[] bytes) {
+			this.name = name;
+			this.bytes = bytes;
+		}
+
 		/**
 		 * źեեDataSource󥹥󥹤֤ޤ
 		 * 
@@ -793,7 +824,13 @@ public class Mail {
 
 			// InputStreamDataSource
 			String contentType = FileTypeMap.getDefaultFileTypeMap().getContentType(name);
-			return new ByteArrayDataSource(is, contentType);
+			if (is != null) {
+				// InputStreamDataSource
+				return new ByteArrayDataSource(is, contentType);
+			} else {
+				// byte󤫤DataSource
+				return new ByteArrayDataSource(bytes, contentType);
+			}
 		}
 
 		/**
@@ -825,6 +862,13 @@ public class Mail {
 		public URL getUrl() {
 			return url;
 		}
+
+		/**
+		 * @return åȤ줿byte󡣤ޤnull
+		 */
+		public byte[] getBytes() {
+			return bytes;
+		}
 	}
 
 	/**
